const QUERY = '+';

const EXPECTED = {
    'others': [
        { 'path': 'std::ops', 'name': 'AddAssign' },
        { 'path': 'std::ops', 'name': 'Add' },
        { 'path': 'core::ops', 'name': 'AddAssign' },
        { 'path': 'core::ops', 'name': 'Add' },
    ],
};
